@@ -3,6 +3,8 @@
 #' @param coocepso list of drug names sorted by frequency co-occuring with EpSO
 #' @param coocesso list of drug names sorted by frequency co-occuring with ESSO
 #' @param coocepi list of drug names sorted by frequency co-occuring with EPILONT
+#' @param coocepisem list of drug names sorted by frequency co-occuring with EPISEM
+#' @param coocfenics list of drug names sorted by frequency co-occuring with FENICS
 #'
 #' @return result table containin the aggregated list of drug terms and their associations
 #'
@@ -16,10 +18,15 @@
 #' utils::data(rawDrugNamesCoOcEpSO, package="epos")
 #' utils::data(rawDrugNamesCoOcESSO, package="epos")
 #' utils::data(rawDrugNamesCoOcEPILONT, package="epos")
+#' utils::data(rawDrugNamesCoOcEPISEM, package="epos")
+#' utils::data(rawDrugNamesCoOcFENICS, package="epos")
 #' createBaseTable(coocepso = rawDrugNamesCoOcEpSO[1:150],
 #'   coocesso=rawDrugNamesCoOcESSO[1:150],
-#'   coocepi=rawDrugNamesCoOcEPILONT[1:150])
-createBaseTable <- function (coocepso, coocesso, coocepi) {
+#'   coocepi=rawDrugNamesCoOcEPILONT[1:150],
+#'   coocepisem=rawDrugNamesCoOcEPISEM[1:150],
+#'   coocfenics=rawDrugNamesCoOcFENICS[1:150])
+createBaseTable <- function (coocepso, coocesso, coocepi, coocepisem, 
+                             coocfenics) {
   atchashda <-
     readAtcMapIntoHashMapDrugNamesAtcCodes(
       system.file("extdata", "db-atc.map", package = "epos"), "\t")
@@ -36,24 +43,33 @@ createBaseTable <- function (coocepso, coocesso, coocepi) {
   tepso <- coocepso
   tesso <- coocesso
   tepi <- coocepi
+  tepisem <- coocepisem
+  tfenics <- coocfenics
   
-  lepso <- genDictListFromRawFreq(tepso)
-  neuroepso <- filterNeuroDrugs(lepso, atchashda)
+  neuroepso <- filterNeuroDrugs(tepso, atchashda)
   
-  lesso <- genDictListFromRawFreq(tesso)
-  neuroesso <- filterNeuroDrugs(lesso, atchashda)
+  neuroesso <- filterNeuroDrugs(tesso, atchashda)
   
-  lepi <- genDictListFromRawFreq(tepi)
-  neuroepi <- filterNeuroDrugs(lepi, atchashda)
+  neuroepi <- filterNeuroDrugs(tepi, atchashda)
   
-  ml <- min (c(length(neuroepso), length(neuroesso), length(neuroepi)))
+  neuroepisem <- filterNeuroDrugs(tepisem, atchashda)
+  
+  neurofenics <- filterNeuroDrugs(tfenics, atchashda)
+  
+  ml <- min (c(length(neuroepso), 
+               length(neuroesso), 
+               length(neuroepi),
+               length(neuroepisem),
+               length(neurofenics)))
   
   dneuro <-
     data.frame(EpSO = neuroepso[1:ml],
                ESSO = neuroesso[1:ml],
-               EPILONT = neuroepi[1:ml])
+               EPILONT = neuroepi[1:ml],
+               EPISEM = neuroepisem[1:ml],
+               FENICS = neurofenics[1:ml])
   
-  dneuromaxk <- TopKLists::calculate.maxK(dneuro, 3, 5, 10)
+  dneuromaxk <- TopKLists::calculate.maxK(dneuro, 5, 5, 5)
   
   neurospace <- as.character(dneuromaxk$topkspace)
   
