@@ -5,6 +5,8 @@ test_that("Test function createNeuroTable()", {
   utils::data(rawDrugNamesCoOcEpSO, package="epos")
   utils::data(rawDrugNamesCoOcESSO, package="epos")
   utils::data(rawDrugNamesCoOcEPILONT, package="epos")
+  utils::data(rawDrugNamesCoOcEPISEM, package="epos")
+  utils::data(rawDrugNamesCoOcFENICS, package="epos")
   atchashda <-
     readAtcMapIntoHashMapDrugNamesAtcCodes(
       system.file("extdata", "db-atc.map", package = "epos"), "\t")
@@ -17,18 +19,23 @@ test_that("Test function createNeuroTable()", {
   tepso <- rawDrugNamesCoOcEpSO
   tesso <- rawDrugNamesCoOcESSO
   tepi <- rawDrugNamesCoOcEPILONT
-  lepso <- genDictListFromRawFreq(tepso)
-  neuroepso <- filterNeuroDrugs(lepso, atchashda)
-  lesso <- genDictListFromRawFreq(tesso)
-  neuroesso <- filterNeuroDrugs(lesso, atchashda)
-  lepi <- genDictListFromRawFreq(tepi)
-  neuroepi <- filterNeuroDrugs(lepi, atchashda)
+  tepisem <- rawDrugNamesCoOcEPISEM
+  tfenics <- rawDrugNamesCoOcFENICS
+
+  neuroepso <- filterNeuroDrugs(tepso, atchashda)
+  neuroesso <- filterNeuroDrugs(tesso, atchashda)
+  neuroepi <- filterNeuroDrugs(tepi, atchashda)
+  neuroepisem <- filterNeuroDrugs(tepisem, atchashda)
+  neurofenics <- filterNeuroDrugs(tfenics, atchashda)
+  
   dneuro <-
     data.frame(EpSO = neuroepso[1:210],
                ESSO = neuroesso[1:210],
-               EPILONT = neuroepi[1:210])
-  dneuromaxk <- TopKLists::calculate.maxK(dneuro, 3, 5, 10)
+               EPILONT = neuroepi[1:210],
+               EPISEM = neuroepisem[1:210],
+               FENICS = neurofenics[1:210])
+  dneuromaxk <- TopKLists::calculate.maxK(dneuro, 5, 5, 5)
   neurospace <- as.character(dneuromaxk$topkspace)
   neurotable <- createNeuroTable(atchashda, atchashsec, dneuromaxk)
-  expect_that(length(neurotable), equals(14))
+  expect_that(length(neurotable), equals(16))
 })
\ No newline at end of file
