@@ -5,22 +5,36 @@ test_that("Test function createTanimotoBaseline()", {
   utils::data(rawDrugNamesCoOcEpSO, package="epos")
   utils::data(rawDrugNamesCoOcESSO, package="epos")
   utils::data(rawDrugNamesCoOcEPILONT, package="epos")
+  utils::data(rawDrugNamesCoOcEPISEM, package="epos")
+  utils::data(rawDrugNamesCoOcFENICS, package="epos")
   atchashda <-
     readAtcMapIntoHashMapDrugNamesAtcCodes(
       system.file("extdata", "db-atc.map", package = "epos"), "\t")
-  tepso <- genDictListFromRawFreq(rawDrugNamesCoOcEpSO)
+  atchashaa <-
+    readAtcMapIntoHashMapAtcCodesAtcNames(
+      system.file("extdata", "db-atc.map", package = "epos"), "\t")
+  atchashsec <-
+    readSecondLevelATC(
+      system.file("extdata", "atc-secondlevel.map", package = "epos"), "\t")
+  tepso <- rawDrugNamesCoOcEpSO
+  tesso <- rawDrugNamesCoOcESSO
+  tepi <- rawDrugNamesCoOcEPILONT
+  tepisem <- rawDrugNamesCoOcEPISEM
+  tfenics <- rawDrugNamesCoOcFENICS
+  
   neuroepso <- filterNeuroDrugs(tepso, atchashda)
-  utils::data(rawDrugBankCoOcESSO, package="epos")
-  tesso <- genDictListFromRawFreq(rawDrugNamesCoOcESSO)
   neuroesso <- filterNeuroDrugs(tesso, atchashda)
-  utils::data(rawDrugBankCoOcEPILONT, package="epos")
-  tepi <- genDictListFromRawFreq(rawDrugNamesCoOcEPILONT)
   neuroepi <- filterNeuroDrugs(tepi, atchashda)
+  neuroepisem <- filterNeuroDrugs(tepisem, atchashda)
+  neurofenics <- filterNeuroDrugs(tfenics, atchashda)
+  
   dneuro <-
     data.frame(EpSO = neuroepso[1:210],
                ESSO = neuroesso[1:210],
-               EPILONT = neuroepi[1:210])
-  dneuromaxk <- TopKLists::calculate.maxK(dneuro, 3, 5, 10)
+               EPILONT = neuroepi[1:210],
+               EPISEM = neuroepisem[1:210],
+               FENICS = neurofenics[1:210])
+  dneuromaxk <- TopKLists::calculate.maxK(dneuro, 5, 5, 5)
   tanimotobaseline <- createTanimotoBaseline(neuroepso, neuroesso, neuroepi, dneuromaxk)
   expect_that(length(tanimotobaseline), equals(9))
 })
\ No newline at end of file
